      subroutine env_check(chan, sat, sat_z, env_dat, l_bt, 
     & h_bt, tol, flag)

c     Function to perform Merchant envelope threshold test

c   I/O LIST:
      implicit        none
c        >>> Inputs <<<
      integer         chan      ! channel combination 3/11=0 11/12=1
      integer         sat       ! sat ID 70, 74, 78 convert to pointer
                                ! satellite # G8=0, G10=1, G12=2
      integer         sat_z     ! satellite zenith angle (rad-1)*1000
      real            env_dat(432) ! BT threshold data array
      integer         l_bt      ! Lower wavelength BT
      integer         h_bt      ! Upper wavelength BT
      integer         tol       ! tolerance BT*10
c        >>> Output <<<
      integer         flag      ! Flag to indicate result
                                ! 1=pass, -1=fail high, -2=fail low
                                ! -3=fail BT range, 0=fail other

c   Local varaibles
      integer         bt_pointer ! indicates with BT range l_bt is in
      integer         pointer   ! array indice of 1st of threshold #s
      real            t_min, t_max ! max and min BT thresholds
      real            bt_diff   ! l_bt - h_bt
      real            sec_sza   ! satellite zenith angle in radians
      real            c1, c2    ! constants for calculating t_min & t_max

c        >>> convert satellite ID to a value for calculating pointer <<<
      if (sat .eq. 70 .or. sat .eq. 78) then
         sat = 0
      else if (sat .eq. 74) then
         sat = 1
      endif

c        >>> calc sec_sza (converts from NOAA to SNM (radians)) <<<
      sec_sza = (sat_z/1000.0)+1

c        >>> calc the number of the BT range where l_bt lies <<<
      bt_pointer = (((l_bt-2670.0)/2.0)/10.0)

c        >>> calc the array indice of the 1st threshold # to read <<<
c        >>> addition of 1 to pointer as fortran counts indices from 1 <<<
      if (sec_sza .gt. 1.5) then ! takes 3-6
         pointer = ((sat*216)+(chan*108)+(bt_pointer*6)+2) + 1
         c1 = 1.5
         c2 = 2.0
      else                      ! takes 1-4
         pointer = (sat*216)+(chan*108)+(bt_pointer*6) + 1
         c1 = 1.0
         c2 = 1.5
      endif


c        >>> calculate the min and max BT thresholds <<<
      t_min = (((sec_sza - c1)/0.5)*env_dat(pointer+2) + 
     & ((c2 - sec_sza)/0.5)*env_dat(pointer))*10.0

      t_max = (((sec_sza - c1)/0.5)*env_dat(pointer+3) + 
     & ((c2 - sec_sza)/0.5)*env_dat(pointer+1))*10.0

c        >>> calc the bt_diff <<<
      bt_diff = l_bt - h_bt

c        >>> calc the value of the result flag <<<
      if (bt_diff .ge. (t_min - tol) .AND. (bt_diff .le. (t_max + tol))
     & .AND. (t_min .le. t_max)) then
         flag = 1   ! pass

         else if ((bt_diff .ge. (t_max + tol)) .AND. (t_min .lt. t_max))
     & then
            flag = -1   ! fail high
 
            else if (bt_diff .le. (t_min - tol) .AND. 
     & (t_min .lt. t_max)) then
               flag = -2   ! fail low

               else if (t_min .ge. t_max) then
                  flag = -3   ! fail BT
                  
               else
                  flag = 0
                  endif
                  

      end

