/* --- facetnormal4_.c --- */

/* 4/12/01
 SNM
 Function to calculate sec(facet normal for specular reflection)
 Inputs - satellite and solar azimuth and zenith angles
          s_azim = sun_a
          s_zen = sun_z_rad
          o_azim = sat_a
          o_zen = sat_z_rad
          Azimuths N=0, W+ve
 Output - sec_theta_n (sec(facet normal for spec. reflctn))
*/

#include <stdio.h>
#include <math.h>

float facetnormal4_(float *s_zen, float *s_azim, float *o_zen, float *o_azim)
{

  float a, costwoomega, cosomega, theta_n, sec_theta_n;

  a=pow((2.0+2.0*sin(*o_zen)*sin(*s_zen)*(cos(*o_azim)*cos(*s_azim) + sin(*o_azim)*sin(*s_azim)) +2.0*cos(*o_zen)*cos(*s_zen)),-0.5);

  costwoomega=sin(*o_zen)*sin(*s_zen)*(cos(*o_azim)*cos(*s_azim) + sin(*o_azim)*sin(*s_azim)) + cos(*o_zen)*cos(*s_zen);


  if ((costwoomega > 1.01) || (costwoomega < -1.01))
    {
      return -1;
    }
  cosomega = pow((0.5 * (costwoomega + 1.0)), 0.5);

  theta_n = acos( (1.0/(2.0*cosomega))*(cos(*s_zen) + cos(*o_zen)) );

  /* if theta_n is infinite, set theta_n = 0 */
    if ((theta_n == HUGE_VAL) ||  (theta_n == -HUGE_VAL))
    {
      theta_n = 0.0;
    }

  sec_theta_n = 1.0/cos(theta_n);

  /* return sec(facet normal) for specular reflection */
    return sec_theta_n;

}
