/* --- glintradiance_.c --- */

/* 4/12/01
 SNM
 Function to calculate the glint radiance
 Inputs - rho     (reflectivity of water)
          p = prob    (probability of facet occurrence)
          sec_theta_n  (sec(facet normal for spec. reflctn))
	  o_zen = sat_z_rad    (satellite zenith angle (rad))
 Output - glint radiance
*/

#include <stdio.h>
#include <math.h>

float glintradiance_(float *rho, float *p, float *sec_theta_n, float *o_zen)
{
  float sun_solid_angle, sol_rad;
  float pi = 3.14159265;
  float glint_rad;

  sun_solid_angle = 4.0*pi*0.000005398843;
  sol_rad = 230.644;

  /* equation from the report...
"GOES SST - Algorithm Improvement for Operational Implementation"
  */
  glint_rad = ((*rho**p*pow(*sec_theta_n,4)) / (4.0*cos(*o_zen))) * sun_solid_angle* sol_rad;

  /* return the glint radiance */
  return glint_rad;

}
