      subroutine rad_to_dbt(glint_rad, o_zen, bt_3,
     & rad_bt_dat, dbt)

c     Function to convert radiance to brightness temperature
c     and calculate the difference BT
c   I/O List
      implicit        none
c        >>> Inputs <<<
      real            glint_rad ! glint radiance
      real            o_zen     ! satellite zenith angle (rad)
      integer         bt_3      ! 3.9 BT (K*10)
      real            rad_bt_dat(4096) ! LUT
c      	(from /data/goes8_radbt_edit.txt' - G8, 
c             /data/goes10_radbt_edit.txt' - G10)

c        >>> Outputs <<<
      real            dbt       ! difference BT

c        >>> Local Variables <<<
      integer         n       ! counter
c        >>> temp vairables for calculations <<<
      real            diff
      real            c37_rad, bt_1, bt_2, rad_1, rad_2
      real            c37_noglintrad, c37_noglintbt
      real            glint_rad2  !glint radiance in GVAR units
      real            pixel_bt  !BT in K

c        >>> K*10 to K <<<
      pixel_bt = bt_3/10.0

c        >>> convert JM units to GVAR units and estimate sun-pixel 
c            transmission (*1000)(/2) >> * 500 <<<<<
c
      glint_rad2 = glint_rad*500.0

c        >>> initialise counter <<<
      n=3

c        >>> find location in LUT where pixel BT lies
c        >>> i.e. the two closest values
c        >* I.E. read thru values from radbt....txt
c        >* 2nd column is radiance
c        >* thrid column is brightness temperature
c        >* reading thru third column to find tow rows, to interpolate radiance


ccc   diff = pixel_bt - rad_bt_dat(0)
      diff = pixel_bt - rad_bt_dat(3)

      do while (diff .gt. 0)

         diff = pixel_bt - rad_bt_dat(n)
         n = n+4

         end do

c         >>> assign LUT  values to variables for calculation of radiance
         bt_1 = rad_bt_dat(n-8)
         bt_2 = rad_bt_dat(n-4)
         rad_1 = rad_bt_dat(n-9)
         rad_2 = rad_bt_dat(n-5)

c        >>> equation to calculate radiance
	 c37_rad = ( (pixel_bt - bt_1)/(bt_2 - bt_1) ) * rad_2 + 
     &		   ( (bt_2 - pixel_bt)/(bt_2 - bt_1) ) * rad_1

c        >>> calculate glint free radiance
         c37_noglintrad = c37_rad - glint_rad2

c        >>> conversion rad to BT <<<
c        >* Now going the other direction:
c        >* computing bt for revised (glint-corrected) radiance

         n=2
ccc      diff = c37_noglintrad - rad_bt_dat(0)
         diff = c37_noglintrad - rad_bt_dat(2)

         do while (diff .gt. 0)

            diff = c37_noglintrad - rad_bt_dat(n)
            n = n+4
            
            end do

c        >>> assign LUT values to variables for calculation of BT<<<
            rad_1 = rad_bt_dat(n-8)
            rad_2 = rad_bt_dat(n-4)
            bt_1 = rad_bt_dat(n-7)
            bt_2 = rad_bt_dat(n-3)


c        >>> equation to calculate BT <<<

	    c37_noglintbt = ( (c37_noglintrad-rad_1)/(rad_2-rad_1) ) * bt_2 +
     &			    ( (rad_2-c37_noglintrad)/(rad_2-rad_1) ) * bt_1

c        >>> calculate BT difference <<<
            dbt = pixel_bt - c37_noglintbt

      end
