/* ftptimelinux.c
   Written by Bill Godfrey
   Written March 21 1997
   Updated June 17 1999

   This program invokes the sftp command and then kills it
   if it does not complete within 120 seconds.

   Log of changes:
    15Jun99 - support more than just hostname.
     Support up to 3 args passed to sftp.
     Tracing now activated by timeout value > 999.
    16Jun99 - use execlp instead of execl,
     so we don't have to specify the full path.
     Support up to 4 args passed to sftp.
     Use fprintf to stderr instead of printf.
    17Jun99 - change help text.

     To compile on hpux, use -Aa -D_HPUX_SOURCE
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>
#include <sys/wait.h>
#include <signal.h>

/* stdio.h  has printf, fopen, fseek, ftell, fread, fclose,
                fgetc, EOF, FILE, stdin, sprintf            */
/* stdlib.h has atol, strtol, exit */
/* string.h has strcpy     */
/* unistd.h has fork,execlp     */
/* sys/wait.h has wait     */
/* signal.h has kill     */
 
/* void main(argc, argv)
   int argc;
   char *argv[]; */
int main(int argc, char * argv[])
{
 int args,argo,itime,ii,jj,trace;
 int pid1,pid2,status,retval;
 char ctime[81];
 char carg1[81];
 char carg2[81];
 char carg3[81];
 char carg4[81];
 char cpath[81];
 char cprog[81];
 
 args=argc-1;
 argo = args;
 
/* if no operands were specified, print some
    help messages and quit. */

 if (args < 1)
 {printf("usage: ftptimelinux [ -seconds ] [sftpargs]\n");
  printf("Version 1.1 - by Bill Godfrey\n");
  printf("This program executes the sftp command and then\n");
  printf("kills it if it does not complete within a time limit.\n");
  printf("By default the time limit is 600 seconds.\n");
  printf("If the first argument is a minus and a number,\n");
  printf("the time limit is set to that number of seconds.\n");
  printf("All other arguments are passed on to sftp.\n");
  exit(1);}
 
 trace = 0;

 strcpy(cpath,"sftp");
 strcpy(cprog,"sftp");

 retval = 0;
 itime = 600;
 ii = 1;

 /* if first arg is -nn (nn being 1 or more decimal digits)
    set itime to the value of nn
    and bump ii so the arg won't be passed to sftp. */

 strcpy(ctime,argv[1]); /* -seconds */
 if ((ctime[0] == '-') && (strlen(ctime) > 1)
  && (ctime[1] >= '0') && (ctime[1] <= '9'))
  {
   itime = 0 - atoi(ctime);
   if (itime > 1000)
    {
     itime = itime - 1000;
     trace = 1;
    }
   ii++;
   argo--;
  }

 if (itime < 1)
   { fprintf(stderr,"invalid switch: %s\n",ctime);
     exit(1);}

 if (argo >= 5)
   { fprintf(stderr,"too many args, maximum is 4\n");
     exit(1);}
 
 if (argo >= 1) strcpy(carg1,argv[ii]);
 if (argo >= 2) strcpy(carg2,argv[ii+1]);
 if (argo >= 3) strcpy(carg3,argv[ii+2]);
 if (argo >= 4) strcpy(carg4,argv[ii+3]);
 if (trace == 1)
  {
   if (argo == 0) printf("no args for sftp\n");
   if (argo >= 1) printf("[%s]\n",carg1);
   if (argo >= 2) printf("[%s]\n",carg2);
   if (argo >= 3) printf("[%s]\n",carg3);
   if (argo >= 4) printf("[%s]\n",carg4);
  }

 if (trace == 1) printf("time limit is %d seconds\n",itime);

 pid1=fork();

 if (pid1 < 0)
   {
     fprintf(stderr,"Unable to create child process 1\n");
     exit(1);
   }

 if (pid1 == 0)
   {
     if (trace == 1) printf("this is child 1 (sftp)\n");
     if      (argo == 0) execlp(cpath,cprog,0);
     else if (argo == 1) execlp(cpath,cprog,carg1,0);
     else if (argo == 2) execlp(cpath,cprog,carg1,carg2,0);
     else if (argo == 3) execlp(cpath,cprog,carg1,carg2,carg3,0);
     else                execlp(cpath,cprog,carg1,carg2,carg3,carg4,0);
     fprintf(stderr,"execlp failed for %s\n",cpath);
     _exit(1);
   }

 pid2=fork();

 if (pid2 < 0)
   {
     fprintf(stderr,"Unable to create child process 2\n");
     kill(pid1,9);
     exit(1);
   }

 if (pid2 == 0)
   {
     if (trace == 1) printf("this is child 2 (sleep)\n");
     sleep(itime);
     _exit(0);
   }

 if (trace == 1) printf("this is parent\n");

 /* wait for either child to complete */

 jj = wait(&status);

 /* if the sftp ended first, kill the delay */
 /* if the sleep ended first, kill the sftp */

 if (jj == pid1)
   {
     retval = WEXITSTATUS(status);
     kill(pid2,9);
   }
 else if (jj == pid2)
   {
     system("date +%Y%j' '%TZ >> errorlogs"); 
     system("ps | grep sftp >> errorlogs"); 
     system("echo KILLING FTP  >> errorlogs"); 
     fprintf(stderr,"killing sftp\n");
     kill(pid1,9);
     retval = 1;
   }
   
 /* wait for kill to complete */
 jj = wait(&status);

 if (trace == 1) printf("done, exit value is %d\n",retval);

 exit(retval);
}
