      subroutine sunglint(windspeed, speed, sat_z_rad, sun_z_rad, jday,
     & hour, minute, orglat, orglon, pxlat, pxlon, glint_rad)

c     Function to perform stages of Merchant/Marsham sunglint test

c     I/O List
      implicit       none
c        >>> Inputs <<<
      real           windspeed         ! (m/s)
      integer        speed          ! speed or velocity
      real           sat_z_rad      ! sat. zenith angle (rad)     
      real           sun_z_rad      ! solar zenith angle (rad)
      integer        jday           !julian day (1-365)
      integer        hour, minute   ! HH, MM
      real           orglat, orglon ! satellite lat and lon
      real           pxlat, pxlon   ! pixel lat and lon
c        >>> lat/lon in degrees, lat = N+ve, lon = [0,360][W to E]
c            G8 is lon = +75 <<<

c        >>> Outputs <<<
      real           glint_rad      ! glint radiance

c        >>> Local Variables <<<
      real           sat_a      ! azimuth angles (rad)
      real           sun_a      ! N=0, W+ve
      real           omega      ! incidence angle for specular reflection
      real            pi
      parameter    (pi = 3.14159265)
      real           a2r	! deg to rad conversion factor
      parameter	     (a2r=pi/180)
      real           rho        ! reflectivity of water
      real           zdeta_x, zdeta_y, zdeta   ! facet tilts
      real	     prob       ! probability of facet occurrence
      real           sec_theta_n  ! sec(facet normal for spec. reflctn)
      real      pxlon2, orglon2  !longitudes [-180,180] E+ve range (rad)
      real      pxlat2          ! pixel latitude (rad)

c        >>> Functions called by Sunglint <<<
      real	angleinc,  waterreflectivity, zdetafacet
      real      cmspeedoccprob, facetnormal4, glintradiance
      real      azimzenangles
      real      sunposition


c       >>> longitude conversion from 0-360 W+ve to -180-180 E+ve <<<
      if (orglon .lt. 180.0) then
         orglon2 = -1.0 * orglon
      else
         orglon2 = 360.0 - orglon
      endif

      if (pxlon .lt. 180.0) then
         pxlon2 = -1.0 * pxlon
      else
         pxlon2 = 360.0 - pxlon
      endif

c       >>> convert latitudes & longitudes from degrees to radians <<<
      pxlat2 = pxlat*a2r
      pxlon2 = pxlon2*a2r
      orglon2 = orglon2*a2r

c       >>> call function to calculate satellite azimuth angle <<<
      sat_a = azimzenangles(pxlat2, pxlon2, orglon2)

c       >>> call function to calculate sun azimuth angle <<<
      sun_a = sunposition(pxlat2, pxlon2, jday, hour, minute)

c		>>> call angleinc <<<
      omega = angleinc(sun_a, sun_z_rad, sat_a, sat_z_rad)

c		>>> call waterreflectivity <<<
      rho = waterreflectivity(omega)

c		>>> call zdetafacet <<<
      zdeta = zdetafacet(sun_z_rad, sun_a, sat_z_rad, sat_a, 
     & zdeta_x, zdeta_y)

c               >>> reset windspeed if < 2m/s <<<
      if (windspeed .lt. 2) then
         windspeed = 2.0
      endif

c		>>> call cmspeedoccprob <<<
      prob = cmspeedoccprob(zdeta_x, zdeta_y, windspeed, speed)

c		>>> call facetnormal4 <<<
      sec_theta_n = facetnormal4(sun_z_rad, sun_a, sat_z_rad, sat_a)

c		>>> call glintradiance <<<
      glint_rad = glintradiance(rho, prob, sec_theta_n, sat_z_rad)

c     >>> return values to the main goes_sst code <<<
      return

      end
