/* --- sunposition_.c --- */

/* 28/01/02
   SNM
   Function to calculate the solar azimuth angle
   Inputs - pxlat2 = pixel latitude   (from nav_pixab3)
            pxlon2 = pixel longitude  (")
	    lat/lon in radians, N+ve, [-180, 180] E+ve
	    jday = Julian day, [1,365]
	    hour = hour HH
	    min = minute MM
   Output - Solar azimuth angle, sun_a (radians) (N =0, W +ve)

GMT/radian, noon at 0,   +ve is afternoon  
delta = eqn of time
Based on Paltridge and Platt Radiative Processes in Meteorology and 
Climatology 3.4-3.10
*/

#include <stdio.h>
#include <math.h>

float sunposition_(float *pxlat2, float *pxlon2, int *jday, int *hour, int *min)

{
  /* declarations */
  float pi = 3.14159265;
  float nday, delta, equation_t, loc_ap_time, a, b, gmt;
  float azimuth;
  float olat, olon;
  int jday2, hour2, min2;

  /* re-assign values to new variable names */
  olat = *pxlat2;
  olon = *pxlon2;
  jday2 = *jday;
  hour2 = *hour;
  min2 = *min;

  gmt = ((hour2-12.0)+(min2/60.0))*pi/12.0;

  nday=2*pi*jday2/365;

  delta=0.006918-0.399912*cos(nday)+0.070257*sin(nday)-0.006758*cos(2*nday)+0.000907*sin(2*nday)-0.002697*cos(3*nday)+0.001480*sin(3*nday);

  equation_t=0.000075+0.001868*cos(nday)-0.032077*sin(nday)-0.014615*cos(2*nday)-0.040849*sin(2*nday);

  /* 4 mins/degree is 229.18 mins/rad */
  loc_ap_time=gmt-equation_t+olon; /* *229.183*2.*pi/(60*24); */
  /* if loc_ap_time le 0. then stop */

  /* eq 3.5 */
  a=sin(delta)*cos(olat)-cos(delta)*sin(olat)*cos(loc_ap_time);
  /* eq 3.6 */
  b=-1.*cos(delta)*sin(loc_ap_time);

  azimuth = atan2(b,a);

  /* convert from (S = 0, E +ve) to (N = 0, W +ve)*/
  azimuth = -1.0 * azimuth;

  if (azimuth <= 0.0)
    {
      azimuth = pi+azimuth;
    }else if (azimuth > 0.0)
      {
	azimuth = azimuth - pi;
      }

  /* return solar azimuth angle */
       /* N = 0, W +ve */
  return azimuth;

}
